Struct zng_state_map::state_map::OccupiedStateMapEntry
source · pub struct OccupiedStateMapEntry<'a, T: StateValue> { /* private fields */ }Expand description
A view into an occupied entry in a state map.
This struct is part of StateMapEntry.
Implementations
sourceimpl<'a, T: StateValue> OccupiedStateMapEntry<'a, T>
impl<'a, T: StateValue> OccupiedStateMapEntry<'a, T>
sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Gets a mutable reference to the value in the entry.
See also into_mut to get a reference tied to the lifetime of the map directly.
sourcepub fn into_mut(self) -> &'a mut T
pub fn into_mut(self) -> &'a mut T
Converts the entry into a mutable reference to the value in the entry with a lifetime bound to the map itself.