StateValue

Trait StateValue 

pub trait StateValue:
    Any
    + Send
    + Sync { }
Represents a type that can be a StateId value.

Trait Alias

This trait is used like a type alias for traits and is already implemented for all types it applies to.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Any + Send + Sync> StateValue for T