pub trait StateValue: Any + Send + Sync + 'static { }
Represents a type that can be a StateId value.
StateId
This trait is used like a type alias for traits and is already implemented for all types it applies to.